==> kubernetes-model-autoscaling-4.10.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/HorizontalPodAutoscalerListFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface HorizontalPodAutoscalerListFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public A setToItems(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public A addToItems(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler... items);
    public A addAllToItems(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> items);
    public A removeFromItems(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler... items);
    public A removeAllFromItems(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> items);
    public A removeMatchingFromItems(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> getItems();
    public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> buildItems();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildItem(int index);
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildFirstItem();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildLastItem();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    public Boolean hasMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    public A withItems(List<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> items);
    public A withItems(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler... items);
    public Boolean hasItems();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerFluent<HorizontalPodAutoscalerListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}


}

==> kubernetes-model-autoscaling-5.0.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta1/HorizontalPodAutoscalerListFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface HorizontalPodAutoscalerListFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public A setToItems(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public A addToItems(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler... items);
    public A addAllToItems(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> items);
    public A removeFromItems(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler... items);
    public A removeAllFromItems(Collection<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> items);
    public A removeMatchingFromItems(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> getItems();
    public List<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> buildItems();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildItem(int index);
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildFirstItem();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildLastItem();
    public io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler buildMatchingItem(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    public A withItems(List<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler> items);
    public A withItems(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler... items);
    public Boolean hasItems();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> addNewItemLike(io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> setNewItemLike(int index,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscaler item);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editItem(int index);
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editFirstItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editLastItem();
    public HorizontalPodAutoscalerListFluent.ItemsNested<A> editMatchingItem(Predicate<io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.autoscaling.v2beta1.HorizontalPodAutoscalerFluent<HorizontalPodAutoscalerListFluent.ItemsNested<N>> {

        public N and();
        public N endItem();    }


}
